@@ -1,10 +1,11 @@
 from __future__ import annotations
 from beartype.typing import TypeVar
+from beartype.typing import TypedDict
+from beartype.typing import Any
 
 from pecs_framework._types import Bases, Namespace
 from pecs_framework.events import EntityEvent
 
-import json
 import sys
 import traceback
 
@@ -14,19 +15,19 @@ class ComponentMeta(type):
     comp_id: str
     cbit: int
     _entity_id: str
-    
+
     def __new__(
-            cls: type[ComponentMeta], 
-            clsname: str, 
-            bases: Bases, 
-            namespace: Namespace,
-        ) -> ComponentMeta:
+        cls: type[ComponentMeta],
+        clsname: str,
+        bases: Bases,
+        namespace: Namespace,
+    ) -> ComponentMeta:
         clsobj = super().__new__(cls, clsname, bases, namespace)
         clsobj.comp_id = clsname.upper()
         clsobj.cbit = 0
         return clsobj
-    
-    
+
+
 class Component(metaclass=ComponentMeta):
     """Root Component class that all components extend."""
     _entity_id: str
@@ -49,7 +50,7 @@ class Component(metaclass=ComponentMeta):
 
     def on_event(self, evt: EntityEvent) -> EntityEvent | None:
         pass
-    
+
 
 # Type variable ranging over Component instances
 CT = TypeVar("CT", bound=Component)
